Package: rnaturalearth
Title: World Map Data from Natural Earth
Version: 1.2.0
Authors@R: c(
  person(
    family = "Massicotte",
    given = "Philippe",
    email = "pmassicotte@hotmail.com",
    role = c("aut", "cre"),
    comment = c(ORCID = "0000-0002-5919-4116")
  ),
  person(
    family = "South",
    given = "Andy",
    email = "southandy@gmail.com",
    role = c("aut")
  ),
  person(
    family = "Hufkens",
    given = "Koen",
    email = "koen.hufkens@gmail.com",
    role = c("ctb"),
    comment = c(ORCID = "0000-0002-5070-8109")
  ))
Description: Facilitates mapping by making natural earth map data from <https://www.naturalearthdata.com/> more easily available to R users.
License: MIT + file LICENSE
LazyData: true
LazyDataCompression: xz
Encoding: UTF-8
URL: https://docs.ropensci.org/rnaturalearth/,
        https://github.com/ropensci/rnaturalearth,
        https://docs.ropensci.org/rnaturalearthhires/
BugReports: https://github.com/ropensci/rnaturalearth/issues
Additional_repositories: https://ropensci.r-universe.dev
Depends: R (>= 3.1.1)
Imports: cli, httr (>= 1.1.0), jsonlite, sf (>= 0.3-4), terra, utils
        (>= 3.2.3)
Suggests: pak, dplyr, ggplot2, ggrepel, knitr (>= 1.12.3), lifecycle
        (>= 1.0.3), pbapply, purrr, rlang, rmarkdown, rnaturalearthdata
        (>= 1.0.0), rnaturalearthhires (>= 1.0.0), testthat (>= 0.9.1),
        tmap
Config/Needs/website: ropensci/rnaturalearthhires
VignetteBuilder: knitr
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-19 14:12:33 UTC; filoche
Author: Philippe Massicotte [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5919-4116>),
  Andy South [aut],
  Koen Hufkens [ctb] (ORCID: <https://orcid.org/0000-0002-5070-8109>)
Maintainer: Philippe Massicotte <pmassicotte@hotmail.com>
Repository: CRAN
Date/Publication: 2026-01-19 17:20:02 UTC
