# Generated by roxygen2: do not edit by hand

export(check_data_exist)
export(check_rnaturalearthdata)
export(check_rnaturalearthhires)
export(install_rnaturalearthdata)
export(install_rnaturalearthhires)
export(ne_coastline)
export(ne_countries)
export(ne_download)
export(ne_file_name)
export(ne_find_vector_data)
export(ne_load)
export(ne_states)
