#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom sf as_Spatial
#' @importFrom terra vect
#' @importFrom utils read.csv
#' @import httr
#' @importFrom jsonlite fromJSON
## usethis namespace: end
NULL
