#' world country polygons from Natural Earth
#'
#' at 1:110m scale (small). Other data and resolutions are in the packages
#' rnaturalearthdata and rnaturalearthhires.
#'
#' @format A \code{sf} object.
#'
#' @slot data A data frame with country attributes.
#'
#' @aliases countries110
#'
#' @name countries
NULL
#'
#' @source
#' \url{https://naciscdn.org/naturalearth/10m/cultural/ne_10m_admin_0_countries.zip}
#'
#' @rdname countries
"countries110"
#'
#' list of cultural layers available from Natural Earth
#'
#' @format A \code{DataFrame}
#' @aliases df_layers_cultural
#' @name df_layers_cultural
#'
NULL

#' @rdname df_layers_cultural
"df_layers_cultural"

#' list of physical layers available from Natural Earth
#'
#'
#' @format A \code{DataFrame}
#' @aliases df_layers_physical
#' @name df_layers_physical
#'
NULL

#' @rdname df_layers_physical
"df_layers_physical"
